@@ -3,6 +3,7 @@
 #include "common/properties.h"
 #include "common/parsing.h"
 #include "common/io/io.h"
+#include "common/processing.h"
 #include "detection/terminalshell/terminalshell.h"
 #include "detection/displayserver/displayserver.h"
 #include "util/mallocHelper.h"
@@ -145,13 +146,7 @@ static void detectXFCETerminal(FFTerminalFontResult* terminalFont)
         });
     }
 
-    if (!configFound)
-    {
-        ffStrbufSetStatic(&terminalFont->error, "Couldn't find xfce4/xfconf/xfce-perchannel-xml/xfce4-terminal.xml or xfce4/terminal/terminalrc");
-        return;
-    }
-
-    if(useSysFont.length == 0 || ffStrbufIgnCaseCompS(&useSysFont, "false") == 0)
+    if(configFound && (useSysFont.length == 0 || ffStrbufIgnCaseCompS(&useSysFont, "false") == 0))
     {
         if(fontName.length == 0)
             ffStrbufAppendF(&terminalFont->error, "Couldn't find FontName in %s", path);
@@ -271,9 +266,9 @@ static void detectXterm(FFTerminalFontResult* terminalFont)
     ffFontInitValues(&terminalFont->font, fontName.chars, fontSize.chars);
 }
 
-static void detectSt(FFTerminalFontResult* terminalFont, uint32_t pid)
+static void detectSt(FFTerminalFontResult* terminalFont, const FFTerminalResult* terminal)
 {
-    FF_STRBUF_AUTO_DESTROY size = ffStrbufCreateF("/proc/%u/cmdline", pid);
+    FF_STRBUF_AUTO_DESTROY size = ffStrbufCreateF("/proc/%u/cmdline", terminal->pid);
     FF_STRBUF_AUTO_DESTROY font = ffStrbufCreate();
     if (!ffAppendFileBuffer(size.chars, &font))
     {
@@ -282,20 +277,53 @@ static void detectSt(FFTerminalFontResult* terminalFont, uint32_t pid)
     }
 
     const char* p = memmem(font.chars, font.length, "\0-f", sizeof("\0-f")); // find parameter of `-f`
-    if (!p)
+    if (p)
     {
-        ffStrbufAppendF(&terminalFont->error, "st was not executed with `-f` parameter");
-        return;
+        // st was executed with `-f` parameter
+        ffStrbufSubstrAfter(&font, (uint32_t) (p + (sizeof("\0-f") - 1) - font.chars));
+        ffStrbufRecalculateLength(&font);
+    }
+    else
+    {
+        ffStrbufClear(&font);
+        if (ffProcessAppendStdOut(&font, (char* const[]) {
+            "strings",
+            terminal->exePath.chars,
+            NULL,
+        }) != NULL || font.length == 0)
+        {
+            ffStrbufAppendS(&terminalFont->error, "Failed to run `strings st`");
+            return;
+        }
+
+        // Search font config string in st binary
+        uint32_t middleIndex = ffStrbufFirstIndexS(&font, "size=");
+        if (middleIndex == font.length)
+        {
+            ffStrbufAppendS(&terminalFont->error, "No font config found in st binary");
+            return;
+        }
+
+        uint32_t startIndex = ffStrbufPreviousIndexC(&font, middleIndex, '\n');
+        if (startIndex == font.length) startIndex = 0;
+        uint32_t endIndex = ffStrbufNextIndexC(&font, middleIndex, '\n');
+
+        ffStrbufSubstrBefore(&font, endIndex);
+        ffStrbufSubstrAfter(&font, startIndex);
     }
 
-    ffStrbufSubstrAfter(&font, (uint32_t) (p + (sizeof("\0-f") - 1) - font.chars));
-    ffStrbufRecalculateLength(&font);
+    // JetBrainsMono Nerd Font Mono:pixelsize=12:antialias=true:autohint=true
 
-    // `monospace:size=15` || `monospace` || `:size=15`
-    uint32_t index = ffStrbufFirstIndexS(&font, ":size=");
+    uint32_t index = ffStrbufFirstIndexC(&font, ':');
     if (index != font.length)
     {
-        ffStrbufSetS(&size, font.chars + index + strlen(":size="));
+        uint32_t sIndex = ffStrbufNextIndexS(&font, index + 1, "size=");
+        if (sIndex != font.length)
+        {
+            sIndex += strlen("size=");
+            uint32_t sIndexEnd = ffStrbufNextIndexC(&font, sIndex, ':');
+            ffStrbufSetNS(&size, sIndexEnd - sIndex, font.chars + sIndex);
+        }
         ffStrbufSubstrBefore(&font, index);
     }
     else
@@ -303,6 +331,47 @@ static void detectSt(FFTerminalFontResult* terminalFont, uint32_t pid)
     ffFontInitValues(&terminalFont->font, font.chars, size.chars);
 }
 
+static void detectWarp(FFTerminalFontResult* terminalFont)
+{
+    FF_STRBUF_AUTO_DESTROY baseDir = ffStrbufCreateA(64);
+
+    FF_LIST_FOR_EACH(FFstrbuf, dirPrefix, instance.state.platform.configDirs)
+    {
+        //We need to copy the dir each time, because it used by multiple threads, so we can't directly write to it.
+        ffStrbufSet(&baseDir, dirPrefix);
+        ffStrbufAppendS(&baseDir, "warp-terminal/user_preferences.json");
+
+        yyjson_doc* doc = yyjson_read_file(baseDir.chars, YYJSON_READ_INSITU | YYJSON_READ_ALLOW_TRAILING_COMMAS | YYJSON_READ_ALLOW_COMMENTS, NULL, NULL);
+        if (!doc) continue;
+
+        yyjson_val* prefs = yyjson_obj_get(yyjson_doc_get_root(doc), "prefs");
+        if (yyjson_is_obj(prefs))
+        {
+            const char* fontName = yyjson_get_str(yyjson_obj_get(prefs, "FontName"));
+            if (!fontName) fontName = "Hack";
+            const char* fontSize = yyjson_get_str(yyjson_obj_get(prefs, "FontSize"));
+            if (!fontSize) fontSize = "13";
+
+            ffFontInitValues(&terminalFont->font, fontName, fontSize);
+        }
+        yyjson_doc_free(doc);
+        return;
+    }
+}
+
+static void detectWestonTerminal(FFTerminalFontResult* terminalFont)
+{
+    FF_STRBUF_AUTO_DESTROY font = ffStrbufCreate();
+    FF_STRBUF_AUTO_DESTROY size = ffStrbufCreate();
+    ffParsePropFileConfigValues("weston.ini", 2, (FFpropquery[]) {
+        {"font=", &font},
+        {"font-size=", &size},
+    });
+    if (!font.length) ffStrbufSetStatic(&font, "DejaVu Sans Mono");
+    if (!size.length) ffStrbufSetStatic(&size, "14");
+    ffFontInitValues(&terminalFont->font, font.chars, size.chars);
+}
+
 void ffDetectTerminalFontPlatform(const FFTerminalResult* terminal, FFTerminalFontResult* terminalFont)
 {
     if(ffStrbufIgnCaseEqualS(&terminal->processName, "konsole"))
@@ -330,5 +399,9 @@ void ffDetectTerminalFontPlatform(const FFTerminalResult* terminal, FFTerminalFo
     else if(ffStrbufIgnCaseEqualS(&terminal->processName, "xterm"))
         detectXterm(terminalFont);
     else if(ffStrbufIgnCaseEqualS(&terminal->processName, "st"))
-        detectSt(terminalFont, terminal->pid);
+        detectSt(terminalFont, terminal);
+    else if(ffStrbufIgnCaseEqualS(&terminal->processName, "warp"))
+        detectWarp(terminalFont);
+    else if(ffStrbufIgnCaseEqualS(&terminal->processName, "weston-terminal"))
+        detectWestonTerminal(terminalFont);
 }
