@@ -61,7 +61,7 @@ void ffLogoPrintChars(const char* data, bool doColorReplacement)
 
     FF_STRBUF_AUTO_DESTROY result = ffStrbufCreateA(2048);
 
-    if (instance.config.display.brightColor)
+    if (!instance.config.display.pipe && instance.config.display.brightColor)
         ffStrbufAppendS(&result, FASTFETCH_TEXT_MODIFIER_BOLT);
 
     ffStrbufAppendNC(&result, options->paddingTop, '\n');
@@ -70,7 +70,7 @@ void ffLogoPrintChars(const char* data, bool doColorReplacement)
     instance.state.logoHeight = options->paddingTop;
 
     //Use logoColor[0] as the default color
-    if(doColorReplacement)
+    if(doColorReplacement && !instance.config.display.pipe)
         ffStrbufAppendF(&result, "\e[%sm", options->colors[0].chars);
 
     while(*data != '\0')
@@ -113,7 +113,7 @@ void ffLogoPrintChars(const char* data, bool doColorReplacement)
             ffStrbufAppendS(&result, "\e[");
             data += 2;
 
-            while(isdigit(*data) || *data == ';')
+            while(ffCharIsDigit(*data) || *data == ';')
                 ffStrbufAppendC(&result, *data++); // number
 
             //We have a valid control sequence, print it and continue with next char
@@ -143,19 +143,27 @@ void ffLogoPrintChars(const char* data, bool doColorReplacement)
                 continue;
             }
 
-            //Map the number to an array index, so that '1' -> 0, '2' -> 1, etc.
-            int index = ((int) *data) - 49;
-
-            //If the index is valid, print the color. Otherwise continue as normal
-            if(index < 0 || index >= FASTFETCH_LOGO_MAX_COLORS)
+            if(!instance.config.display.pipe)
             {
-                ffStrbufAppendC(&result, '$');
-                ++currentlineLength;
-                //Don't continue here, we want to print the current char as unicode
+                //Map the number to an array index, so that '1' -> 0, '2' -> 1, etc.
+                int index = ((int) *data) - 49;
+
+                //If the index is valid, print the color. Otherwise continue as normal
+                if(index < 0 || index >= FASTFETCH_LOGO_MAX_COLORS)
+                {
+                    ffStrbufAppendC(&result, '$');
+                    ++currentlineLength;
+                    //Don't continue here, we want to print the current char as unicode
+                }
+                else
+                {
+                    ffStrbufAppendF(&result, "\e[%sm", options->colors[index].chars);
+                    ++data;
+                    continue;
+                }
             }
             else
             {
-                ffStrbufAppendF(&result, "\e[%sm", options->colors[index].chars);
                 ++data;
                 continue;
             }
@@ -188,7 +196,8 @@ void ffLogoPrintChars(const char* data, bool doColorReplacement)
         }
     }
 
-    ffStrbufAppendS(&result, FASTFETCH_TEXT_MODIFIER_RESET);
+    if(!instance.config.display.pipe)
+        ffStrbufAppendS(&result, FASTFETCH_TEXT_MODIFIER_RESET);
 
     if(!options->separate)
     {
@@ -210,13 +219,25 @@ void ffLogoPrintChars(const char* data, bool doColorReplacement)
     ffWriteFDBuffer(FFUnixFD2NativeFD(STDOUT_FILENO), &result);
 }
 
-static void logoApplyColors(const FFlogo* logo)
+static void logoApplyColors(const FFlogo* logo, bool replacement)
 {
     if(instance.config.display.colorTitle.length == 0)
         ffStrbufAppendS(&instance.config.display.colorTitle, logo->colorTitle ? logo->colorTitle : logo->colors[0]);
 
     if(instance.config.display.colorKeys.length == 0)
         ffStrbufAppendS(&instance.config.display.colorKeys, logo->colorKeys ? logo->colorKeys : logo->colors[1]);
+
+    if (replacement)
+    {
+        FFOptionsLogo* options = &instance.config.logo;
+
+        const char* const* colors = logo->colors;
+        for(int i = 0; *colors != NULL && i < FASTFETCH_LOGO_MAX_COLORS; i++, colors++)
+        {
+            if(options->colors[i].length == 0)
+                ffStrbufAppendS(&options->colors[i], *colors);
+        }
+    }
 }
 
 static bool logoHasName(const FFlogo* logo, const FFstrbuf* name, bool small)
@@ -292,30 +313,16 @@ static const FFlogo* logoGetBuiltinDetected(FFLogoSize size)
     return &ffLogoUnknown;
 }
 
-static inline void logoApplyColorsDetected(void)
-{
-    logoApplyColors(logoGetBuiltinDetected(FF_LOGO_SIZE_NORMAL));
-}
-
 static void logoPrintStruct(const FFlogo* logo)
 {
-    logoApplyColors(logo);
-
-    FFOptionsLogo* options = &instance.config.logo;
-
-    const char* const* colors = logo->colors;
-    for(int i = 0; *colors != NULL && i < FASTFETCH_LOGO_MAX_COLORS; i++, colors++)
-    {
-        if(options->colors[i].length == 0)
-            ffStrbufAppendS(&options->colors[i], *colors);
-    }
+    logoApplyColors(logo, true);
 
     ffLogoPrintChars(logo->lines, true);
 }
 
 static void logoPrintNone(void)
 {
-    logoApplyColorsDetected();
+    logoApplyColors(logoGetBuiltinDetected(FF_LOGO_SIZE_NORMAL), false);
     instance.state.logoHeight = 0;
     instance.state.logoWidth = 0;
 }
@@ -348,8 +355,8 @@ static bool logoPrintData(bool doColorReplacement)
     if(options->source.length == 0)
         return false;
 
+    logoApplyColors(logoGetBuiltinDetected(FF_LOGO_SIZE_NORMAL), doColorReplacement);
     ffLogoPrintChars(options->source.chars, doColorReplacement);
-    logoApplyColorsDetected();
     return true;
 }
 
@@ -393,11 +400,12 @@ static bool logoPrintFileIfExists(bool doColorReplacement, bool raw)
         : !ffAppendFileBuffer(options->source.chars, &content)
     )
     {
-        fprintf(stderr, "Logo: Failed to load file content from logo source: %s \n", options->source.chars);
+        if (instance.config.display.showErrors)
+            fprintf(stderr, "Logo: Failed to load file content from logo source: %s \n", options->source.chars);
         return false;
     }
 
-    logoApplyColorsDetected();
+    logoApplyColors(logoGetBuiltinDetected(FF_LOGO_SIZE_NORMAL), doColorReplacement);
     if(raw)
         ffLogoPrintCharsRaw(content.chars, content.length);
     else
@@ -411,7 +419,7 @@ static bool logoPrintImageIfExists(FFLogoType logo, bool printError)
     if(!ffLogoPrintImageIfExists(logo, printError))
         return false;
 
-    logoApplyColorsDetected();
+    logoApplyColors(logoGetBuiltinDetected(FF_LOGO_SIZE_NORMAL), false);
     return true;
 }
 
@@ -421,12 +429,12 @@ static bool logoTryKnownType(void)
 
     if(options->type == FF_LOGO_TYPE_NONE)
     {
-        logoApplyColorsDetected();
+        logoApplyColors(logoGetBuiltinDetected(FF_LOGO_SIZE_NORMAL), false);
         return true;
     }
 
     if(options->type == FF_LOGO_TYPE_BUILTIN)
-        return logoPrintBuiltinIfExists(&options->source, FF_LOGO_SIZE_NORMAL);
+        return logoPrintBuiltinIfExists(&options->source, FF_LOGO_SIZE_UNKNOWN);
 
     if(options->type == FF_LOGO_TYPE_SMALL)
         return logoPrintBuiltinIfExists(&options->source, FF_LOGO_SIZE_SMALL);
@@ -448,21 +456,15 @@ static bool logoTryKnownType(void)
     if(options->type == FF_LOGO_TYPE_IMAGE_RAW)
         return logoPrintFileIfExists(false, true);
 
-    return logoPrintImageIfExists(options->type, true);
-}
-
-static void logoPrintKnownType(void)
-{
-    if(!logoTryKnownType())
-        logoPrintDetected(FF_LOGO_SIZE_UNKNOWN);
+    return logoPrintImageIfExists(options->type, instance.config.display.showErrors);
 }
 
 void ffLogoPrint(void)
 {
-    //In pipe mode, we don't have a logo or padding.
+    //When generate JSON result, we don't have a logo or padding.
     //We also don't need to set main color, because it won't be printed anyway.
     //So we can return quickly here.
-    if(instance.config.display.pipe || instance.state.resultDoc)
+    if(instance.state.resultDoc)
     {
         instance.state.logoHeight = 0;
         instance.state.logoWidth = 0;
@@ -487,7 +489,17 @@ void ffLogoPrint(void)
     //If the source and source type is set to something else than auto, always print with the set type.
     if(options->source.length > 0 && options->type != FF_LOGO_TYPE_AUTO)
     {
-        logoPrintKnownType();
+        if(!logoTryKnownType())
+        {
+            if (instance.config.display.showErrors)
+            {
+                // Image logo should have been handled
+                if(options->type == FF_LOGO_TYPE_BUILTIN || options->type == FF_LOGO_TYPE_SMALL)
+                    fprintf(stderr, "Logo: Failed to load %s logo: %s \n", options->type == FF_LOGO_TYPE_BUILTIN ? "builtin" : "builtin small", options->source.chars);
+            }
+
+            logoPrintDetected(FF_LOGO_SIZE_UNKNOWN);
+        }
         return;
     }
 
