@@ -25,7 +25,7 @@ void ffPrintTheme(FFThemeOptions* options)
     else
     {
         FF_PRINT_FORMAT_CHECKED(FF_THEME_MODULE_NAME, 0, &options->moduleArgs, FF_PRINT_TYPE_DEFAULT, FF_THEME_NUM_FORMAT_ARGS, ((FFformatarg[]){
-            {FF_FORMAT_ARG_TYPE_STRBUF, &theme}
+            {FF_FORMAT_ARG_TYPE_STRBUF, &theme, "combined"},
         }));
     }
 }
@@ -82,7 +82,7 @@ void ffGenerateThemeJsonResult(FF_MAYBE_UNUSED FFThemeOptions* options, yyjson_m
 void ffPrintThemeHelpFormat(void)
 {
     FF_PRINT_MODULE_FORMAT_HELP_CHECKED(FF_THEME_MODULE_NAME, "{1}", FF_THEME_NUM_FORMAT_ARGS, ((const char* []) {
-        "Combined themes"
+        "Combined themes - combined",
     }));
 }
 
