@@ -1,11 +1,10 @@
 #include "common/printing.h"
 #include "common/jsonconfig.h"
+#include "common/time.h"
 #include "detection/users/users.h"
 #include "modules/users/users.h"
 #include "util/stringUtils.h"
 
-#include <time.h>
-
 #pragma GCC diagnostic ignored "-Wformat" // warning: unknown conversion type character 'F' in format
 
 #define FF_USERS_NUM_FORMAT_ARGS 5
@@ -57,12 +56,7 @@ void ffPrintUsers(FFUsersOptions* options)
                     ffStrbufAppendF(&result, "@%s", user->hostName.chars);
 
                 if(user->loginTime)
-                {
-                    char buf[64];
-                    time_t time = (time_t) (user->loginTime / 1000);
-                    strftime(buf, sizeof(buf), "%FT%T%z", localtime(&time));
-                    ffStrbufAppendF(&result, " - login time %s", buf);
-                }
+                    ffStrbufAppendF(&result, " - login time %s", ffTimeToShortStr(user->loginTime));
 
                 ffStrbufPutTo(&result, stdout);
             }
@@ -75,11 +69,11 @@ void ffPrintUsers(FFUsersOptions* options)
             FFUserResult* user = (FFUserResult*)ffListGet(&users, i);
 
             FF_PRINT_FORMAT_CHECKED(FF_USERS_MODULE_NAME, users.length == 1 ? 0 : (uint8_t) (i + 1), &options->moduleArgs, FF_PRINT_TYPE_DEFAULT, FF_USERS_NUM_FORMAT_ARGS, ((FFformatarg[]){
-                {FF_FORMAT_ARG_TYPE_STRBUF, &user->name},
-                {FF_FORMAT_ARG_TYPE_STRBUF, &user->hostName},
-                {FF_FORMAT_ARG_TYPE_STRBUF, &user->sessionName},
-                {FF_FORMAT_ARG_TYPE_STRBUF, &user->clientIp},
-                {FF_FORMAT_ARG_TYPE_UINT64, &user->loginTime},
+                {FF_FORMAT_ARG_TYPE_STRBUF, &user->name, "name"},
+                {FF_FORMAT_ARG_TYPE_STRBUF, &user->hostName, "host-name"},
+                {FF_FORMAT_ARG_TYPE_STRBUF, &user->sessionName, "session-name"},
+                {FF_FORMAT_ARG_TYPE_STRBUF, &user->clientIp, "client-ip"},
+                {FF_FORMAT_ARG_TYPE_STRING, ffTimeToShortStr(user->loginTime), "login-time"},
             }));
         }
     }
@@ -152,7 +146,7 @@ void ffGenerateUsersJsonResult(FF_MAYBE_UNUSED FFUsersOptions* options, yyjson_m
     if(error)
     {
         yyjson_mut_obj_add_str(doc, module, "error", error);
-        goto exit;
+        return;
     }
 
     yyjson_mut_val* arr = yyjson_mut_obj_add_arr(doc, module, "result");
@@ -163,10 +157,13 @@ void ffGenerateUsersJsonResult(FF_MAYBE_UNUSED FFUsersOptions* options, yyjson_m
         yyjson_mut_obj_add_strbuf(doc, obj, "hostName", &user->hostName);
         yyjson_mut_obj_add_strbuf(doc, obj, "sessionName", &user->sessionName);
         yyjson_mut_obj_add_strbuf(doc, obj, "clientIp", &user->clientIp);
-        yyjson_mut_obj_add_uint(doc, obj, "loginTime", user->loginTime);
+        const char* pstr = ffTimeToFullStr(user->loginTime);
+        if (*pstr)
+            yyjson_mut_obj_add_strcpy(doc, obj, "loginTime", pstr);
+        else
+            yyjson_mut_obj_add_null(doc, obj, "loginTime");
     }
 
-exit:
     FF_LIST_FOR_EACH(FFUserResult, user, results)
     {
         ffStrbufDestroy(&user->clientIp);
@@ -179,11 +176,11 @@ exit:
 void ffPrintUsersHelpFormat(void)
 {
     FF_PRINT_MODULE_FORMAT_HELP_CHECKED(FF_USERS_MODULE_NAME, "{1}@{2} - login time {5}", FF_USERS_NUM_FORMAT_ARGS, ((const char* []) {
-        "User name",
-        "Host name",
-        "Session name",
-        "Client IP",
-        "Login Time"
+        "User name - user-name",
+        "Host name - host-name",
+        "Session name - session",
+        "Client IP - client-ip",
+        "Login Time in local timezone - login-time",
     }));
 }
 
